@@ -9,7 +9,7 @@ from .config import Config, ConfigError
 from .paths import default_confpath
 from .pwexpire import check_pw_expiry
 from .state import DomainState
-from .kerberos import setup_kerberos_environ
+from .kerberos import setup_kerberos_environ, KerberosError
 from .version import __version__
 
 
@@ -69,7 +69,7 @@ def connect_ad(func):
         # TODO: Does this belong in ADManager?
         setup_kerberos_environ(
                 username = lc.username,
-                domain = domain,
+                realm = domain,
                 keytab = lc.keytab,
                 cache = lc.cache,
             )
@@ -116,8 +116,7 @@ def cmd_group_assign(ad, args):
 
 @connect_ad
 def cmd_group_list(ad, args):
-    for g in ad.get_groups():
-        print(g)
+    common_list(ad.get_groups(), args.verbose)
 
 
 @connect_ad
@@ -152,10 +151,16 @@ def cmd_user_setupns(ad, args):
 
 
 
+def common_list(things, verbose):
+    for x in things:
+        if verbose:
+            print(x)
+        else:
+            print(x.cn)
+
 @connect_ad
 def cmd_user_list(ad, args):
-    for u in ad.get_users():
-        print(u)
+    common_list(ad.get_users(), args.verbose)
 
 
 @connect_ad
@@ -230,6 +235,8 @@ def parse_args():
             help="File to which changes are logged")
     ap.add_argument('-c', '--config', default=default_confpath(),
             help="Path to config file")
+    ap.add_argument('-v', '--verbose', action='store_true',
+            help="Show verbose output")
 
     sub = ap.add_subparsers(dest='command_name', metavar='COMMAND')
     sub.required = True     # https://stackoverflow.com/a/18283730/119527
@@ -337,6 +344,8 @@ def run_app(args):
         args.func(args)
     except AssignmentError as e:
         raise AppError(e)
+    except KerberosError as e:
+        raise AppError(e)
 
 
 def main():
